# Security Policy

Security and stability is very important for Propan.

Learn more about it below. 👇

## Versions

The latest version of Propan is supported.

You are encouraged to write tests for your application and update your Propan version frequently after ensuring that your tests are passing. This way you will benefit from the latest features, bug fixes, and **security fixes**.

## Reporting a Vulnerability

If you think you have identified a security issue, and even if you are not sure about it, please report it right away. But, **do not open a public issue**.

To responsibly report a security issue, please navigate to the Security tab for the repo and click *"Report a vulnerability"*.

![Screenshot of repo security tab showing "Report a vulnerability" button](https://github.com/encode/.github/raw/master/img/github-demos-private-vulnerability-reporting.png)

Alternatively, you can send me an email to: diementros@yandex.ru

Be sure to include as much detail as necessary in your report. As with reporting normal issues, a minimal reproducible example will help to fix the issue faster.

Also, please add to your report output of following command:
```bash
$ propan --version
```

## Public Discussions

Please restrain from publicly discussing a potential security vulnerability. 🙊

It's better to discuss privately and try to find a solution first, to limit the potential impact as much as possible.

---

Thanks for your help!
